@@ -10,11 +10,12 @@ import math
 from django.db.models import Max
 from django.db import transaction
 
+from departments.common.config import BadRequestCode, ServerErrorCode
 from departments.models import Department, DepartmentUserMap
 from departments.forms.forms import (
     DepartmentForms,
 )
-from departments.utils.error_response import Response
+from departments.utils.error_response import Resp
 
 
 def get_departments(organization_id: int, department_name: str = None) -> dict:
@@ -63,7 +64,7 @@ def get_departments(organization_id: int, department_name: str = None) -> dict:
             })
             items.append(lst)
 
-    return Response(data=items)
+    return Resp(data=items)
 
 
 def get_sub_department(organization_id: int, department_id=None) -> dict:
@@ -87,7 +88,7 @@ def get_sub_department(organization_id: int, department_id=None) -> dict:
                 "path": department.path,
 
             })
-        return Response(data=department_items)
+        return Resp(data=department_items)
 
     instance = Department.objects.get(
         pk=department_id,
@@ -101,9 +102,10 @@ def get_sub_department(organization_id: int, department_id=None) -> dict:
         is_deleted=False,
         path=department_path
     )
-    return Response(data=[{"id": i.id, "name": i.name, "charger_id": i.charger_id, "path": i.path} for i in department])
+    return Resp(data=[{"id": i.id, "name": i.name, "charger_id": i.charger_id, "path": i.path} for i in department])
 
 
+@transaction.atomic
 def create_department(data: dict) -> dict:
     """
     新建部门
@@ -120,7 +122,7 @@ def create_department(data: dict) -> dict:
     checked = DepartmentForms(data)
     # 判断数据合法性
     if not checked.is_valid():
-        return Response(code=500, msg="error", data=checked.errors)
+        return Resp(code=ServerErrorCode, msg="error", data=checked.errors)
     # 构造path
     parent_id = data.pop("parent_id")
     parent = Department.objects.get(pk=parent_id)
@@ -131,11 +133,21 @@ def create_department(data: dict) -> dict:
         path = [parent.id]
     # 找到最大排序数
     show_order = Department.objects.aggregate(num=Max('show_order'))["num"]
-    data["path"] = path
     data["show_order"] = show_order + 1
+    data["path"] = path
+    # 查询当前添加的部门同一级别是否有重复
+    same_level_department = Department.objects.filter(
+        name=data["name"],
+        path=path,
+        organization_id=data["organization_id"]
+    ).exists()
+
+    # 如果当前部门下有这个部门
+    if same_level_department:
+        return Resp(code=ServerErrorCode, msg="error", data=f"[{data['name']}]在当前部门下已存在, 请使用其他名称")
 
     department_instance = Department.objects.create(**data)
-    return Response(data={'id': department_instance.pk})
+    return Resp(data={'id': department_instance.pk})
 
 
 def get_department_object(organization_id: int, pk: int):
@@ -147,11 +159,11 @@ def get_department_object(organization_id: int, pk: int):
     """
     try:
         instance = Department.objects.get(pk=pk, organization_id=organization_id, is_deleted=False)
-        return Response(
+        return Resp(
             data={"id": instance.id, "name": instance.name, "path": instance.path, "charger_id": instance.charger_id}
         )
     except Department.DoesNotExist:
-        return Response(code=500, msg="error", data=f"the department can't be found  id: {pk}")
+        return Resp(code=ServerErrorCode, msg="error", data=f"the department can't be found  id: {pk}")
 
 
 @transaction.atomic
@@ -165,7 +177,7 @@ def update_department(pk: int, data: dict):
     checked = DepartmentForms(data)
     # 判断数据合法性
     if not checked.is_valid():
-        return Response(code=500, msg="error", data=checked.errors)
+        return Resp(code=ServerErrorCode, msg="error", data=checked.errors)
     organization_id = data["organization_id"]
     try:
         instance = Department.objects.get(pk=pk, organization_id=organization_id, is_deleted=False)
@@ -192,7 +204,7 @@ def update_department(pk: int, data: dict):
         instance.name = data["name"]
         instance.charger_id = data["charger_id"]
         instance.save()
-        return Response(data="修改成功")
+        return Resp(data="修改成功")
     except Exception as err:
         raise ValueError(f"{str(err)}  id: {pk}")
 
@@ -204,8 +216,8 @@ def delete_department(organization_id: int, pk: int):
     :param pk:
     :return:
     """
-    Department.objects.filter(organization_id=organization_id, pk=pk).update(is_deleted=True)
-    return Response(data="删除成功")
+    Department.objects.filter(organization_id=organization_id, pk=pk).delete()
+    return Resp(data="删除成功")
 
 
 @transaction.atomic
@@ -220,7 +232,7 @@ def add_department_user_map(organization_id: int, department_id: int, user_ids:
     if not Department.objects.filter(
             organization_id=organization_id, pk=department_id
     ).exists():
-        return Response(code=400, msg="error", data="当前组织没有该部门")
+        return Resp(code=BadRequestCode, msg="error", data="当前组织没有该部门")
 
     department_user_list = [
         DepartmentUserMap(department_id=department_id, user_id=user) for user in user_ids
@@ -229,7 +241,7 @@ def add_department_user_map(organization_id: int, department_id: int, user_ids:
         DepartmentUserMap.objects.bulk_create(department_user_list)
     except Exception as err:
         raise Exception(err)
-    return Response(data="添加成功")
+    return Resp(data="添加成功")
 
 
 def get_department_user(organization_id: int, department_id: int, page: int, size: int):
@@ -252,7 +264,7 @@ def get_department_user(organization_id: int, department_id: int, page: int, siz
         item for item in user_ids.order_by("-id").values_list("user_id", flat=True)[(page-1)*size: page*size]
     ] if page <= max_page else []
 
-    return Response(data={
+    return Resp(data={
         "total": total,
         "page_range": [i for i in range(1, max_page+1)],
         "current_page": page,
@@ -271,11 +283,11 @@ def delete_department_user_map(organization_id: int, department_id: int, user_id
     if not Department.objects.filter(
             organization_id=organization_id, pk=department_id
     ).exists():
-        return Response(code=400, msg="error", data="当前组织没有该部门")
+        return Resp(code=BadRequestCode, msg="error", data="当前组织没有该部门")
 
     DepartmentUserMap.objects.filter(
         department__organization_id=organization_id,
         user_id__in=user_ids
     ).delete()
 
-    return Response(data="移除成功")
+    return Resp(data="移除成功")
