@@ -5,7 +5,8 @@
 @Time        : 2022/4/28 2:25 下午
 @Description :
 """
-from departments.utils.error_response import Response
+from departments.common.config import ServerErrorCode, BadRequestCode
+from departments.utils.error_response import Resp
 from departments.utils.department_funcs import (
     get_departments,
     get_sub_department,
@@ -42,7 +43,7 @@ class DepartmentViewSet(object):
         elif type_ == "sub":
             return get_sub_department(self.organization_id, department_id)
         else:
-            return Response(code=500, msg="error", data="failed params")
+            return Resp(code=ServerErrorCode, msg="error", data="failed params")
 
     def create(self, data: dict):
         """
@@ -58,7 +59,7 @@ class DepartmentViewSet(object):
         try:
             return update_department(pk, data)
         except Exception as err:
-            return Response(code=500, msg="error", data=str(err))
+            return Resp(code=ServerErrorCode, msg="error", data=str(err))
 
     def delete(self, pk: int):
         return delete_department(self.organization_id, pk)
@@ -90,7 +91,7 @@ class DepartmentViewSet(object):
         try:
             return add_department_user_map(self.organization_id, department_id, user_ids)
         except Exception as err:
-            return Response(code=400, msg="error", data=str(err))
+            return Resp(code=BadRequestCode, msg="error", data=str(err))
 
     def delete_department_user(self, department_id: int, user_ids: list):
         """
